pub struct SerializedLayout(/* private fields */);Expand description
Managed memory metadata package for export/import.
This is the wire format for transmitting layout metadata between workers. It contains everything needed to reconstruct remote layouts and load their NIXL registration data.
Implementations
Sourceimpl SerializedLayout
impl SerializedLayout
Sourcepub fn pack(
worker_address: WorkerAddress,
nixl_metadata: Vec<u8>,
layouts: Vec<LogicalLayoutDescriptor>,
) -> Result<Self>
pub fn pack( worker_address: WorkerAddress, nixl_metadata: Vec<u8>, layouts: Vec<LogicalLayoutDescriptor>, ) -> Result<Self>
Sourcepub fn from_bytes(bytes: Vec<u8>) -> Self
pub fn from_bytes(bytes: Vec<u8>) -> Self
Create from raw bytes.